# -*- coding: utf-8 -*-

import doctest
import unittest
import menhir.contenttype.image
import zope.component
import zope.security.management as security

from zope.component.testlayer import ZCMLFileLayer
from zope.site.folder import rootFolder
from zope.site.site import LocalSiteManager
from zope.security.testing import Principal, Participation
from zope.traversing.interfaces import ITraversable
from zope.traversing.testing import setUp
from zope.container.interfaces import ISimpleReadContainer
from zope.container.traversal import ContainerTraversable


class MenhirTestLayer(ZCMLFileLayer):

    def setUp(self):
        ZCMLFileLayer.setUp(self)
        zope.component.hooks.setHooks()

        # Set up site
        site = rootFolder()
        site.setSiteManager(LocalSiteManager(site))

        # Set up traversal
        setUp()
        zope.component.provideAdapter(
            ContainerTraversable, (ISimpleReadContainer,), ITraversable)

        zope.component.hooks.setSite(site)
        security.newInteraction(Participation(Principal('zope.mgr')))

    def tearDown(self):
        zope.component.hooks.resetHooks()
        zope.component.hooks.setSite()
        security.endInteraction()
        ZCMLFileLayer.tearDown(self)


def test_suite():
    suite = unittest.TestSuite()
    readme = doctest.DocFileSuite(
        'README.txt',
        globs={"__name__": "menhir.contenttype.image"},
        optionflags=(doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS))
    readme.layer = MenhirTestLayer(menhir.contenttype.image)
    suite.addTest(readme)
    return suite



#!/usr/bin/python
# -*- coding: utf-8 -*-

from megrok import resource
from hurry.slimbox import slimbox


class ImagePopup(resource.ResourceLibrary):
    resource.path('resources')
    resource.name("image.popup")
    resource.resource("popup.js", depends=[slimbox])



from zope.i18nmessageid import MessageFactory

MF = MessageFactory('menhir.contenttype.image')

from menhir.contenttype.image.image import IImage, Image
from menhir.contenttype.image.library import ImagePopup



# -*- coding: utf-8 -*-

import dolmen.content as content

from dolmen.file import ImageField
from dolmen.blob import BlobProperty
from dolmen.app.content import icon
from dolmen.app.security.content import CanAddContent
from menhir.contenttype.image import MF as _


class IImage(content.IBaseContent):
    """Defines a simple object that contains an image.
    """
    image = ImageField(
        title=_(u"Image"),
        required=True)


class Image(content.Content):
    """A simple image storing its data in a blob.
    """
    icon("image.png")
    content.name(_(u"Image"))
    content.schema(IImage)
    content.require(CanAddContent)

    image = BlobProperty(IImage['image'])



# -*- coding: utf-8 -*-

from os.path import join
from setuptools import setup, find_packages

version = '0.2'
name = 'menhir.contenttype.image'

history = open(join('docs', 'HISTORY.txt')).read()
readme = open(
    join('src', 'menhir', 'contenttype', 'image', 'README.txt')).read()

tests_require = [
    'zope.app.publisher',
    'zope.component',
    'zope.container',
    'zope.principalregistry',
    'zope.publisher',
    'zope.security',
    'zope.securitypolicy',
    'zope.site',
    'zope.traversing',
    ]

setup(name = name,
      version = version,
      description = 'Dolmen content-type extension : image',
      long_description = readme[readme.find('\n\n'):] + '\n' + history,
      keywords = 'Grok Zope3 CMS Dolmen',
      author = 'Souheil Chelfouh',
      author_email = 'souheil@chelfouh.com',
      url = 'http://tracker.trollfot.org/',
      download_url = 'http://pypi.python.org/pypi/menhir.contenttype.image',
      license = 'GPL',
      packages=find_packages('src', exclude=['ez_setup']),
      package_dir={'': 'src'},
      namespace_packages = ['menhir', 'menhir.contenttype'],
      include_package_data = True,
      platforms = 'Any',
      zip_safe = False,
      tests_require = tests_require,
      extras_require = {'test': tests_require},
      install_requires=[
          'dolmen.app.content',
          'dolmen.app.layout',
          'dolmen.app.security',
          'dolmen.blob',
          'dolmen.content',
          'dolmen.file',
          'dolmen.thumbnailer',
          'dolmen.widget.image',
          'grokcore.view',
          'hurry.slimbox',
          'megrok.resource',
          'setuptools',
          'zope.i18nmessageid',
          'zope.size',
      ],
      classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Zope3',
        'Intended Audience :: Other Audience',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
      ],
)



# -*- coding: utf-8 -*-

import grokcore.view as grok
import dolmen.app.layout as layout

from menhir.contenttype.image import IImage, ImagePopup
from zope.size import ISized


class ImageView(layout.Index):
    """Default view for an image.
    """
    grok.context(IImage)

    def update(self):
        ImagePopup.need()
        url = self.url(self.context)
        self.size = ISized(self.context.image).sizeForDisplay()
        self.thumbnail = "%s/++thumbnail++image.preview" % url
        self.popup_url = "%s/++thumbnail++image.large" % url
        self.download_url = "%s/++download++image" % url
